# Credits

## Development Lead

* [Ströer Online Marketing / RegioHelden GmbH](https://stroeer-online-marketing.de/)  
  <entwicklung+opensource@regiohelden.de>

## Contributors (in order of first contribution)

* [Leo Antunes](https://github.com/costela)
* [Marco De Felice](https://github.com/md-f)
* [Charlie Denton](https://github.com/meshy)
* [Jens Nistler](https://github.com/lociii)
* [Benedikt Bauer](https://github.com/mastacheata)
* [Ronny Vedrilla](https://github.com/GitRon)
* [Mounir Messelmeni](https://github.com/MounirMesselmeni)
* [Mihaela Sofinet](https://github.com/airiulola)
